guitool_ibeis
=============

|GithubActions| |Pypi| |Downloads| |Codecov| 

Helpers for PyQt5 GUI development for the IBEIS project.

Depends on `vtool_ibeis` and `utool`.

GUI Tools - tools for making guis. Part of the WildMe / IBEIS Project.


Repos relevant to the IBEIS project:

* https://github.com/Erotemic/plottool_ibeis

* https://github.com/Erotemic/guitool_ibeis

* https://github.com/Erotemic/dtool_ibeis

* https://github.com/Erotemic/vtool_ibeis

* https://github.com/Erotemic/pyflann_ibeis

* https://github.com/Erotemic/pyhesaff

* https://github.com/Erotemic/utool

* https://github.com/Erotemic/ibeis


.. |CircleCI| image:: https://circleci.com/gh/Erotemic/guitool_ibeis.svg?style=svg
    :target: https://circleci.com/gh/Erotemic/guitool_ibeis
.. |Travis| image:: https://img.shields.io/travis/Erotemic/guitool_ibeis/main.svg?label=Travis%20CI
   :target: https://travis-ci.org/Erotemic/guitool_ibeis?branch=main
.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/github/Erotemic/guitool_ibeis?branch=main&svg=True
   :target: https://ci.appveyor.com/project/Erotemic/guitool_ibeis/branch/main
.. |Codecov| image:: https://codecov.io/github/Erotemic/guitool_ibeis/badge.svg?branch=main&service=github
   :target: https://codecov.io/github/Erotemic/guitool_ibeis?branch=main
.. |Pypi| image:: https://img.shields.io/pypi/v/guitool_ibeis.svg
   :target: https://pypi.python.org/pypi/guitool_ibeis
.. |Downloads| image:: https://img.shields.io/pypi/dm/guitool_ibeis.svg
   :target: https://pypistats.org/packages/guitool_ibeis
.. |ReadTheDocs| image:: https://readthedocs.org/projects/guitool_ibeis/badge/?version=latest
    :target: http://guitool_ibeis.readthedocs.io/en/latest/
.. |GithubActions| image:: https://github.com/Erotemic/guitool_ibeis/actions/workflows/tests.yml/badge.svg?branch=main
    :target: https://github.com/Erotemic/guitool_ibeis/actions?query=branch%3Amain
